import {
  createPromise
} from "./chunk-FSDCRQB3.js";

// src/common/pipes/rpc.ts
var rpcCounter = 1;
var defaultSerialize = async (i) => i;
var defaultDeserialize = defaultSerialize;
function setupRPCBasic(options, functions, eventNames = []) {
  const {
    post,
    on,
    serialize = defaultSerialize,
    deserialize = defaultDeserialize,
    log
  } = options;
  const rpcPromiseMap = /* @__PURE__ */ new Map();
  on(async (data) => {
    try {
      const msg = await deserialize(data);
      const [mode, args, id, method] = msg;
      if (mode === 1 /* request */ || mode === 2 /* event */) {
        let result, error;
        if (method != null) {
          try {
            const fn = functions[method];
            result = await fn(...args);
          } catch (e) {
            error = String(e);
          }
        } else {
          error = "Method implementation missing";
        }
        if (error)
          log?.warn("error", msg, error);
        if (mode === 1 /* request */ && id) {
          const data2 = await serialize(error ? [4 /* reject */, error, id] : [3 /* resolve */, result, id]);
          await post(data2);
        }
      } else if (id) {
        const promise = rpcPromiseMap.get(id);
        if (promise != null) {
          if (mode === 4 /* reject */)
            promise.reject(args);
          else
            promise.resolve(args);
        }
        rpcPromiseMap.delete(id);
      }
    } catch (err) {
      log?.warn("Error on handling RPC data. Invalid?", err, data);
    }
  });
  const proxyHandler = {
    get(_, method) {
      const sendEvent = async (...args) => {
        await post(await serialize([2 /* event */, args, null, method]));
      };
      if (options.onlyEvents || eventNames.includes(method)) {
        sendEvent.asEvent = sendEvent;
        return sendEvent;
      }
      const sendCall = async (...args) => {
        const [promise, resolve, reject] = createPromise();
        const id = rpcCounter++;
        rpcPromiseMap.set(id, { resolve, reject });
        const data = await serialize([1 /* request */, args, id, method]);
        await post(data);
        return promise;
      };
      sendCall.asEvent = sendEvent;
      return sendCall;
    }
  };
  return { post, serialize, rpcPromiseMap, proxyHandler };
}
function useRPCAsync(functions, options) {
  const { eventNames = [] } = options;
  const { proxyHandler } = setupRPCBasic(options, functions, eventNames);
  return new Proxy({}, proxyHandler);
}
function useRPCAsyncHub(options) {
  const eventNames = [];
  const functions = {};
  const { proxyHandler } = setupRPCBasic(options, functions);
  function createRPCProxy() {
    return new Proxy({}, proxyHandler);
  }
  return function(additionalFunctions, additionalEventNames = []) {
    Object.assign(functions, additionalFunctions ?? {});
    eventNames.push(...additionalEventNames);
    return createRPCProxy();
  };
}

export {
  useRPCAsync,
  useRPCAsyncHub
};
//# sourceMappingURL=chunk-MKKWKO4D.js.map