import "../../chunk-HMRSQHLY.js";
import "../../chunk-UMUHNSGZ.js";
import "../../chunk-AFR4TBTH.js";
import {
  bitfield,
  createBinaryStreamDecoder,
  createBinaryStreamEncoder
} from "../../chunk-TPBBZQSO.js";
import "../../chunk-MO24G7VK.js";
import "../../chunk-2PE4OYYB.js";
import "../../chunk-RNL46FQ3.js";
import "../../chunk-MWUFUBY5.js";
import "../../chunk-GKKLBSFA.js";
import "../../chunk-VIMKC4ZH.js";
import "../../chunk-THQONF76.js";
import "../../chunk-FLFB2K34.js";
import "../../chunk-264HKVNG.js";
import "../../chunk-HST4VI64.js";
import "../../chunk-Y4Y2UW4C.js";
import "../../chunk-GZUTQZ3U.js";
import "../../chunk-QFCI276X.js";
import "../../chunk-CZRBSDM4.js";
import "../../chunk-EW6FHLFK.js";
import "../../chunk-KF7VWGCK.js";
import "../../chunk-MPAXUMZ5.js";
import "../../chunk-2GSKQ3JD.js";
import "../../chunk-EMAWKJ2Y.js";
import "../../chunk-UNDIGSHA.js";
import "../../chunk-7OAUULYN.js";
import "../../chunk-2T2C276H.js";
import "../../chunk-ZESYG7WE.js";
import "../../chunk-T77VRAAN.js";
import "../../chunk-CLYTKZXT.js";
import "../../chunk-X356T6ZJ.js";
import "../../chunk-6DVQ64MF.js";
import "../../chunk-DQMBSAP6.js";
import "../../chunk-UMFGZFFE.js";
import "../../chunk-7GOLOL5D.js";
import "../../chunk-RXQQW2PV.js";
import "../../chunk-RVBBTDXC.js";
import "../../chunk-VSJ34R4O.js";
import "../../chunk-QXMTSRRE.js";
import "../../chunk-CFICINSP.js";
import "../../chunk-CRVSXYJ4.js";
import "../../chunk-I45WP5PM.js";
import "../../chunk-MZ2ODZKK.js";
import "../../chunk-ER2NNANC.js";
import "../../chunk-EJVKADTL.js";
import "../../chunk-UHTVWILC.js";
import "../../chunk-UYBQWMJC.js";
import "../../chunk-XSB2WAW2.js";
import "../../chunk-AS5LR4AI.js";
import "../../chunk-5Y3HYG6B.js";
import "../../chunk-AFUVZLZZ.js";
import "../../chunk-WWSHZF6M.js";
import "../../chunk-NYCGHEIN.js";
import "../../chunk-S7CUSMDX.js";
import "../../chunk-FL5CT6MC.js";
import "../../chunk-2HWPZ6ZE.js";
import "../../chunk-HLRQ5H3N.js";
import "../../chunk-5J5P77E5.js";
import "../../chunk-G73H5WQB.js";
import "../../chunk-DGP32WEQ.js";
import "../../chunk-73CVRDI7.js";
import "../../chunk-KG4L5KVT.js";
import "../../chunk-SRGFRO74.js";
import "../../chunk-ACZDEHYB.js";
import "../../chunk-FSDCRQB3.js";
import "../../chunk-YEEGQOIW.js";
import "../../chunk-TWPB455K.js";
import "../../chunk-IZT6OHMS.js";
import "../../chunk-JU2MYLJO.js";
import "../../chunk-HR2TKQFG.js";
import "../../chunk-TYWNSO7K.js";
import "../../chunk-ZMFW3O35.js";
import "../../chunk-5MAHDO36.js";
import "../../chunk-7NSVDPHN.js";
import {
  Uint8ArrayToHexDump,
  toHex
} from "../../chunk-VTQBCMZR.js";
import "../../chunk-6GHO7LQW.js";

// src/common/bin/index.spec.ts
describe("encoder", () => {
  it("should write a stream", () => {
    const stream = createBinaryStreamEncoder();
    stream.writeUint32(1);
    stream.write({ a: "99" });
    stream.writeBytes([1, 2, 3], 3);
    stream.write(123);
    const bin = stream.getUint8Array();
    expect(Uint8ArrayToHexDump(bin)).toMatchInlineSnapshot(`
      "0000  01 00 00 00 76 01 01 61 77 02 39 39 01 02 03 7D  ....v..aw.99...}
      0010  BB 01                                            \xBB.              "
    `);
    expect(stream.getLength()).toBe(18);
    const readStream = createBinaryStreamDecoder(bin);
    expect(readStream.getOffset()).toBe(0);
    expect(readStream.readUint32()).toBe(1);
    expect(readStream.getOffset()).toBe(4);
    expect(readStream.read()).toEqual({ a: "99" });
    expect(readStream.readBytes(3)).toMatchInlineSnapshot(`
Uint8Array [
  1,
  2,
  3,
]
`);
    expect(readStream.read()).toBe(123);
    expect(readStream.getOffset()).toBe(bin.length);
  });
  it("should bitfield", () => {
    const bf = bitfield(1);
    bf.setBit(4);
    expect(bf.getValue()).toBe(17);
    bf.setBit(0, false);
    expect(bf.getValue()).toBe(16);
    bf.setBit(1);
    bf.setBit(5);
    bf.setBit(16);
    expect(bf.getValue().toString(2)).toMatchInlineSnapshot(
      '"10000000000110010"'
    );
    expect(bf.getValue()).toBe(65586);
    expect(bf.getBit(0)).toBe(false);
    expect(bf.getBit(4)).toBe(true);
    bf.toggleBit(4);
    expect(bf.getBit(4)).toBe(false);
    expect(bf.getValue()).toBe(65570);
  });
  it("should var bin", () => {
    function enc(v) {
      const e = createBinaryStreamEncoder();
      e.writeIntVar(v);
      return toHex(e.getUint8Array());
    }
    expect(enc(1)).toMatchInlineSnapshot('"01"');
    expect(enc(128)).toMatchInlineSnapshot('"8002"');
    expect(enc(-1)).toMatchInlineSnapshot('"41"');
    expect(enc(-691529286)).toMatchInlineSnapshot('"c699bf9305"');
    expect(enc(691529286)).toMatchInlineSnapshot('"8699bf9305"');
  });
  it("should var bin uint", () => {
    function enc(v) {
      const e = createBinaryStreamEncoder();
      e.writeUintVar(v);
      return toHex(e.getUint8Array());
    }
    expect(enc(1)).toMatchInlineSnapshot('"01"');
    expect(enc(127)).toMatchInlineSnapshot('"7f"');
    expect(enc(128)).toMatchInlineSnapshot(`"8001"`);
    expect(enc(255)).toMatchInlineSnapshot('"ff01"');
    expect(enc(256)).toMatchInlineSnapshot('"8002"');
    expect(enc(691529286)).toMatchInlineSnapshot('"c6ccdfc902"');
  });
});
//# sourceMappingURL=index.spec.js.map