"use strict";



var _chunkGJ2NCPKVcjs = require('../../chunk-GJ2NCPKV.cjs');

// src/common/data/orderby.spec.ts
describe("order by", () => {
  it("should order correctly", () => {
    expect(_chunkGJ2NCPKVcjs.parseOrderby.call(void 0, "timestamp asc")).toEqual({
      asc: true,
      desc: false,
      field: "timestamp",
      orderby: "asc"
    });
    expect(_chunkGJ2NCPKVcjs.parseOrderby.call(void 0, "timestamp desc")).toEqual({
      asc: false,
      desc: true,
      field: "timestamp",
      orderby: "desc"
    });
    expect(_chunkGJ2NCPKVcjs.parseOrderby.call(void 0, "timestamp xxx")).toEqual({
      asc: true,
      desc: false,
      field: "timestamp",
      orderby: "xxx"
    });
    expect(_chunkGJ2NCPKVcjs.parseOrderby.call(void 0, "timestamp")).toEqual({
      asc: true,
      desc: false,
      field: "timestamp",
      orderby: "asc"
    });
  });
  it("should compose", () => {
    expect(_chunkGJ2NCPKVcjs.composeOrderby.call(void 0, "timestamp")).toEqual("timestamp asc");
    expect(_chunkGJ2NCPKVcjs.composeOrderby.call(void 0, "timestamp", true)).toEqual("timestamp asc");
    expect(_chunkGJ2NCPKVcjs.composeOrderby.call(void 0, "timestamp", false)).toEqual("timestamp desc");
  });
  it("should sort by", () => {
    const values = [
      {
        name: "b"
      },
      {
        name: "a"
      },
      {
        name: "c"
      }
    ];
    expect(_chunkGJ2NCPKVcjs.sortedOrderby.call(void 0, values, "name desc")).toEqual([
      {
        name: "c"
      },
      {
        name: "b"
      },
      {
        name: "a"
      }
    ]);
    expect(_chunkGJ2NCPKVcjs.sortedOrderby.call(void 0, values, "name asc")).toEqual([
      {
        name: "a"
      },
      {
        name: "b"
      },
      {
        name: "c"
      }
    ]);
  });
  it("should sort by2", () => {
    const values = [
      {
        group: 1,
        name: "b"
      },
      {
        group: 1,
        name: "a"
      },
      {
        group: 2,
        name: "c"
      },
      {
        group: 1,
        name: "d"
      }
    ];
    expect(_chunkGJ2NCPKVcjs.sortedOrderby.call(void 0, values, "group desc", "name asc")).toEqual([
      {
        group: 2,
        name: "c"
      },
      {
        group: 1,
        name: "a"
      },
      {
        group: 1,
        name: "b"
      },
      {
        group: 1,
        name: "d"
      }
    ]);
    expect(_chunkGJ2NCPKVcjs.sortedOrderby.call(void 0, values, "group", "name desc")).toEqual([
      {
        group: 1,
        name: "d"
      },
      {
        group: 1,
        name: "b"
      },
      {
        group: 1,
        name: "a"
      },
      {
        group: 2,
        name: "c"
      }
    ]);
  });
});
//# sourceMappingURL=orderby.spec.cjs.map