"use strict";

var _chunkNUAYMDDKcjs = require('../../chunk-NUAYMDDK.cjs');
require('../../chunk-IOP7DGF3.cjs');
require('../../chunk-ZNTN57VN.cjs');
require('../../chunk-HULDJDND.cjs');
require('../../chunk-CXBBK7CI.cjs');
require('../../chunk-4OVLRIUA.cjs');
require('../../chunk-DRTH56G4.cjs');
require('../../chunk-KTC5RW57.cjs');
require('../../chunk-A4VFMLAN.cjs');
require('../../chunk-7XAMJGPO.cjs');
require('../../chunk-MQW5ML2S.cjs');
require('../../chunk-XWE2OTGL.cjs');
require('../../chunk-7BL7WPL3.cjs');
require('../../chunk-MPD2DJAD.cjs');
require('../../chunk-ZGKV237Z.cjs');
require('../../chunk-YELWQAMG.cjs');
require('../../chunk-YZSOTFZT.cjs');
require('../../chunk-NBKYAXXN.cjs');
require('../../chunk-FEYF6QXS.cjs');
require('../../chunk-N7OUNPMM.cjs');
require('../../chunk-BXHLYONU.cjs');
require('../../chunk-DSA7V4QZ.cjs');
require('../../chunk-UXNJ5WZM.cjs');
require('../../chunk-QYCE2TUJ.cjs');
require('../../chunk-ANZPWIO4.cjs');
require('../../chunk-SBGQDG53.cjs');
require('../../chunk-PJXRDQ2A.cjs');
require('../../chunk-GJ2NCPKV.cjs');
require('../../chunk-NUA44STS.cjs');
require('../../chunk-FYLSPYV2.cjs');
require('../../chunk-YKRFYR2Q.cjs');
require('../../chunk-M3E66ROD.cjs');
require('../../chunk-BMRI2X66.cjs');
require('../../chunk-ADJUZEHB.cjs');
require('../../chunk-7FPSHSSO.cjs');

// src/common/log/log.spec.ts
describe("logger", () => {
  it("should log different levels", () => {
    const messages = [];
    const logger = _chunkNUAYMDDKcjs.LoggerContext.call(void 0, );
    function LoggerTestHandler(msg) {
      messages.push(msg);
    }
    logger.setHandlers([LoggerTestHandler]);
    const log = logger("test");
    log("Simple");
    log.debug("Hello");
    log.info("World");
    log.warn("is on");
    log.error("Fire");
    try {
      log.assert(false, "Fatal");
    } catch (err) {
    }
    expect(messages).toEqual([
      {
        level: 0,
        messages: ["Simple"],
        name: "test"
      },
      {
        level: 0,
        messages: ["Hello"],
        name: "test"
      },
      {
        level: 1,
        messages: ["World"],
        name: "test"
      },
      {
        level: 2,
        messages: ["is on"],
        name: "test"
      },
      {
        level: 3,
        messages: ["Fire"],
        name: "test"
      },
      {
        level: 4,
        messages: ["Fatal"],
        name: "test"
      }
    ]);
  });
  it("should log filter level", () => {
    const messages = [];
    function LoggerTestHandler(msg) {
      messages.push(msg);
    }
    const logger = _chunkNUAYMDDKcjs.LoggerContext.call(void 0, );
    logger.setHandlers([LoggerTestHandler]);
    const log = logger("test");
    expect(log.label).toBe("test");
    log.debug("Hello");
    log.info("World");
    log.warn("is on");
    log.error("Fire");
    try {
      log.assert(false, "Fatal");
    } catch (err) {
    }
    expect(messages).toEqual([
      { name: "test", messages: ["Hello"], level: 0 },
      // xxx
      { name: "test", messages: ["World"], level: 1 },
      { name: "test", messages: ["is on"], level: 2 },
      { name: "test", messages: ["Fire"], level: 3 },
      { name: "test", messages: ["Fatal"], level: 4 }
    ]);
    {
      const log2 = log.extend("ext");
      log2.debug("Hello");
      log2.info("World2");
      log2.warn("is on");
      log2.error("Fire");
      try {
        log2.assert(false, "Fatal");
      } catch (err) {
      }
      expect(messages).toEqual([
        { name: "test", messages: ["Hello"], level: 0 },
        // xxx
        { name: "test", messages: ["World"], level: 1 },
        { name: "test", messages: ["is on"], level: 2 },
        { name: "test", messages: ["Fire"], level: 3 },
        { name: "test", messages: ["Fatal"], level: 4 },
        { name: "test:ext", messages: ["Hello"], level: 0 },
        // xxx
        { name: "test:ext", messages: ["World2"], level: 1 },
        { name: "test:ext", messages: ["is on"], level: 2 },
        { name: "test:ext", messages: ["Fire"], level: 3 },
        { name: "test:ext", messages: ["Fatal"], level: 4 }
      ]);
    }
  });
  it("should log filter namespace", () => {
    const messages = [];
    function LoggerTestHandler(msg) {
      messages.push(msg);
    }
    const logger = _chunkNUAYMDDKcjs.LoggerContext.call(void 0, );
    logger.setHandlers([LoggerTestHandler]);
    logger.setFilter("a*,-ab");
    const aa = logger("aa");
    const ab = logger("ab");
    const xy = logger("xy");
    aa("aa");
    ab("ab");
    xy("xy");
    expect(messages).toEqual([
      {
        level: 0,
        messages: ["aa"],
        name: "aa"
      }
    ]);
    const xyz = aa.extend("xyz");
    xyz("xyz");
    expect(messages).toEqual([
      {
        level: 0,
        messages: ["aa"],
        name: "aa"
      },
      {
        level: 0,
        messages: ["xyz"],
        name: "aa:xyz"
      }
    ]);
  });
  it("should fake log", () => {
    const messages = [];
    const logger = _chunkNUAYMDDKcjs.LoggerContext.call(void 0, );
    function LoggerTestHandler(msg) {
      messages.push(msg);
    }
    logger.setHandlers([LoggerTestHandler]);
    const log = logger("test", false);
    const { info, error, warn, debug, assert } = log;
    log("Simple");
    debug("Hello");
    info("World");
    warn("is on");
    error("Fire");
    expect(messages).toEqual([]);
  });
});
//# sourceMappingURL=log.spec.cjs.map