import {
  decodeJson,
  encodeJson
} from "../../chunk-TPBBZQSO.js";
import "../../chunk-MO24G7VK.js";
import "../../chunk-2PE4OYYB.js";
import "../../chunk-RNL46FQ3.js";
import "../../chunk-MWUFUBY5.js";
import "../../chunk-GKKLBSFA.js";
import "../../chunk-QFCI276X.js";
import {
  useRPC,
  useRPCHub
} from "../../chunk-CLYTKZXT.js";
import "../../chunk-7GOLOL5D.js";
import "../../chunk-RXQQW2PV.js";
import "../../chunk-RVBBTDXC.js";
import "../../chunk-VSJ34R4O.js";
import "../../chunk-QXMTSRRE.js";
import "../../chunk-CFICINSP.js";
import "../../chunk-I45WP5PM.js";
import "../../chunk-MZ2ODZKK.js";
import "../../chunk-ER2NNANC.js";
import "../../chunk-EJVKADTL.js";
import "../../chunk-UHTVWILC.js";
import "../../chunk-UYBQWMJC.js";
import "../../chunk-XSB2WAW2.js";
import "../../chunk-AS5LR4AI.js";
import "../../chunk-5Y3HYG6B.js";
import "../../chunk-AFUVZLZZ.js";
import "../../chunk-WWSHZF6M.js";
import "../../chunk-NYCGHEIN.js";
import "../../chunk-S7CUSMDX.js";
import "../../chunk-FL5CT6MC.js";
import "../../chunk-2HWPZ6ZE.js";
import "../../chunk-HLRQ5H3N.js";
import "../../chunk-5J5P77E5.js";
import "../../chunk-G73H5WQB.js";
import "../../chunk-DGP32WEQ.js";
import "../../chunk-73CVRDI7.js";
import "../../chunk-KG4L5KVT.js";
import "../../chunk-SRGFRO74.js";
import "../../chunk-ACZDEHYB.js";
import "../../chunk-FSDCRQB3.js";
import "../../chunk-YEEGQOIW.js";
import "../../chunk-TWPB455K.js";
import "../../chunk-IZT6OHMS.js";
import "../../chunk-JU2MYLJO.js";
import "../../chunk-HR2TKQFG.js";
import "../../chunk-TYWNSO7K.js";
import "../../chunk-ZMFW3O35.js";
import "../../chunk-5MAHDO36.js";
import "../../chunk-7NSVDPHN.js";
import "../../chunk-VTQBCMZR.js";
import "../../chunk-6GHO7LQW.js";

// src/common/msg/rpc.spec.ts
import { MessageChannel } from "node:worker_threads";
var bobCount = 0;
var Bob = {
  hi(name) {
    return `Hi ${name}, I am Bob`;
  },
  bump() {
    bobCount += 1;
  },
  getCount() {
    return bobCount;
  }
};
var Alice = {
  hello(name) {
    return `Hello ${name}, my name is Alice`;
  }
};
describe("rpc", () => {
  beforeEach(() => {
    bobCount = 0;
  });
  it("basic", async () => {
    const channel = new MessageChannel();
    const serialize = (data) => encodeJson(data);
    const deserialize = (data) => decodeJson(data);
    const bob = useRPC(Bob, {
      post: (data) => channel.port1.postMessage(data),
      on: (data) => channel.port1.on("message", data),
      serialize,
      deserialize
    });
    const alice = useRPC(Alice, {
      // mark bob's `bump` as an event without response
      eventNames: ["bump"],
      post: (data) => channel.port2.postMessage(data),
      on: (data) => channel.port2.on("message", data),
      serialize,
      deserialize
    });
    expect(await bob.hello("Bob")).toEqual("Hello Bob, my name is Alice");
    expect(await alice.hi("Alice")).toEqual("Hi Alice, I am Bob");
    expect(alice.bump()).toBeUndefined();
    expect(Bob.getCount()).toBe(0);
    await new Promise((resolve) => setTimeout(resolve, 100));
    expect(Bob.getCount()).toBe(1);
    channel.port1.close();
    channel.port2.close();
  });
  it("hub", async () => {
    const channel = new MessageChannel();
    const serialize = (data) => encodeJson(data);
    const deserialize = (data) => decodeJson(data);
    const bobHub = useRPCHub({
      post: (data) => channel.port1.postMessage(data),
      on: (data) => channel.port1.on("message", data),
      serialize,
      deserialize
    });
    const bob = bobHub(Bob);
    const alice = useRPC(Alice, {
      // mark bob's `bump` as an event without response
      eventNames: ["bump"],
      post: (data) => channel.port2.postMessage(data),
      on: (data) => channel.port2.on("message", data),
      serialize,
      deserialize
    });
    expect(await bob.hello("Bob")).toEqual("Hello Bob, my name is Alice");
    expect(await alice.hi("Alice")).toEqual("Hi Alice, I am Bob");
    expect(alice.bump()).toBeUndefined();
    expect(Bob.getCount()).toBe(0);
    await new Promise((resolve) => setTimeout(resolve, 100));
    expect(Bob.getCount()).toBe(1);
    channel.port1.close();
    channel.port2.close();
  });
});
//# sourceMappingURL=rpc.spec.js.map