import { PipeAsync } from './types.js';
import { LoggerInterface } from '../log/log-base.js';

type ArgumentsType<T> = T extends (...args: infer A) => any ? A : never;
type ReturnType<T> = T extends (...args: any) => infer R ? R : never;
interface RPCOptionsBasic extends PipeAsync {
    /** No return values expected */
    onlyEvents?: boolean;
    /** Custom logger */
    log?: LoggerInterface;
}
interface RPCOptions<Remote> extends RPCOptionsBasic {
    /** Names of remote functions that do not need response. */
    eventNames?: (keyof Remote)[];
}
interface RPCFn<T> {
    /** Call the remote function and wait for the result. */
    (...args: ArgumentsType<T>): Promise<Awaited<ReturnType<T>>>;
    /** Send event without asking for response */
    asEvent: (...args: ArgumentsType<T>) => void;
}
type RPCReturn<RemoteFunctions> = {
    [K in keyof RemoteFunctions]: RPCFn<RemoteFunctions[K]>;
};
declare function useRPCAsync<LocalFunctions, RemoteFunctions = LocalFunctions>(functions: LocalFunctions, options: RPCOptions<RemoteFunctions>): RPCReturn<RemoteFunctions>;
declare function useRPCAsyncHub(options: RPCOptionsBasic): <LocalFunctions, RemoteFunctions = LocalFunctions>(additionalFunctions?: LocalFunctions | undefined, additionalEventNames?: string[]) => RPCReturn<RemoteFunctions>;
type UseRPCAsyncHubType = ReturnType<typeof useRPCAsyncHub>;

export { type ArgumentsType, type RPCFn, type RPCOptions, type RPCOptionsBasic, type RPCReturn, type ReturnType, type UseRPCAsyncHubType, useRPCAsync, useRPCAsyncHub };
